@@ -11,6 +11,65 @@ from scipy.stats import rankdata
 import tqdm
 
 
+def kendall_tau_old(X: np.ndarray, method='A') -> np.float64:
+    '''
+    Multivariate Kendall's tau.
+
+    Parameters
+    ----------
+    X : array-like
+        An m x n data matrix.
+    method : {'A', 'B', 'C'}, optional
+            The method used to account for tied points.
+            The following methods are available (default is 'a'):
+          * 'A': Original Kendall's Tau.
+          * 'B': :math:`\\tau_B = \\frac{m_c - m_d}{\\sqrt[n]{\\prod_{j=1}^{n} (m_0 - m_j)}}`
+          * 'C': :math:`\tau_C = \\frac{2 (m_c - m_d) }{m^2 \\frac{(\\max(m,n) - 1)}{\\max(m,n)}}`
+
+    Returns
+    -------
+     : np.float64
+        Multivariate Kendall's tau score
+
+    Raises
+    ------
+    NotImplementedError : Method B is not implemented yet.
+
+    References
+    ----------
+    .. [1] "Kendall's Tau.", https://en.wikipedia.org/wiki/Kendall_rank_correlation_coefficient
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> data = np.arange(100).reshape(10,10)
+    >>> kendall_tau(data)
+    1.0
+    '''
+
+    concordant = 0
+    discordant = 0
+
+    for i, xi in enumerate(X):
+        for j, xj in enumerate(X):
+            if i < j:
+                if (np.all(xi < xj) or np.all(xi > xj)):
+                    concordant += 1
+                else:
+                    discordant += 1
+            else:
+                continue
+    if method == 'A':
+        return (concordant - discordant) / ((X.shape[0] **2 - X.shape[0]) / 2)
+    elif method == 'B':
+        raise NotImplementedError ('Method B is not implemented yet.')
+    elif method == 'C':
+        m = np.min(X.shape)
+        result =  2 * (concordant - discordant)
+        result /= X.shape[0]**2
+        result /= (m-1) / m
+        return result
+
 def kendall_tau(X: np.ndarray, method='A') -> np.float64:
     '''
     Multivariate Kendall's tau.
@@ -43,36 +102,40 @@ def kendall_tau(X: np.ndarray, method='A') -> np.float64:
     --------
     >>> import numpy as np
     >>> data = np.arange(100).reshape(10,10)
-    >>> estimators.kendall_tau(data)
+    >>> kendall_tau(data)
     1.0
     '''
 
-    concordant = 0
-    discordant = 0
-
-    for i, xi in enumerate(X):
-        for j, xj in enumerate(X):
-            if i < j:
-                if (np.all(xi < xj) or np.all(xi > xj)):
-                    concordant += 1
-                else:
-                    discordant += 1
+    @jit(nopython=True, fastmath=True) # does fastmath actually improve speed here?
+    def grade(q):
+        score = 0
+        for j in range(X.shape[0]):
+            if np.all(X[j] < X[q]) or np.all(X[j] > X[q]):
+                score += 1
             else:
+                score -= 1
+        return score
+    score = 0
+    for i in tqdm.tqdm(range(X.shape[0])):
+        for j in range(X.shape[0]):
+            if np.all(X[i] < X[j]) or np.all(X[i] > X[j]):
+                score += 1
+            elif np.all(X[i] == X[j]):
                 continue
+            else:
+                score -= 1
     if method == 'A':
-        return (concordant - discordant) / ((X.shape[0] **2 - X.shape[0]) / 2)
+        return score / ((X.shape[0] **2 - X.shape[0]))
     elif method == 'B':
         raise NotImplementedError ('Method B is not implemented yet.')
     elif method == 'C':
         m = np.min(X.shape)
-        result =  2 * (concordant - discordant)
+        result =  score
         result /= X.shape[0]**2
         result /= (m-1) / m
         return result
 
 
-
-
 def grade_entropy(X: np.ndarray) -> np.float64:
     '''
     Computes grade entropy for a strict product order
@@ -128,7 +191,7 @@ def grade_entropy(X: np.ndarray) -> np.float64:
 
     '''
     P = np.zeros((X.shape[0], X.shape[0]))
-    @jit(nopython=True, fastmath=True) # does fastmath actually improve speed?
+    @jit(nopython=True, fastmath=True) # does fastmath actually improve speed here?
     def grade(q):
         v = np.zeros(X.shape[0])
         for j in range(X.shape[0]):
@@ -177,7 +240,7 @@ def minkowski_deviation(x: np.ndarray, order=2) -> np.float64:
     5.338539126015656
     '''
     result = x - np.mean(x)
-    result = np.abs(x)
+    result = np.abs(result)
     result = np.power(result, order)
     result = np.mean(result)
     result = np.power(result, 1 / order)
@@ -353,7 +416,7 @@ def spearman_correlation(X: np.ndarray, method='average') -> np.float64:
     --------
     >>> import numpy as np
     >>> data = np.arange(100).reshape(10,10)
-    >>> estimators.spearman_correlation(data)
+    >>> spearman_correlation(data)
     0.9999999999999991
     '''
     transform = rankdata(X, axis=0, method=method)
@@ -361,7 +424,7 @@ def spearman_correlation(X: np.ndarray, method='average') -> np.float64:
     return reflective_correlation(transform)
 
 def angular_disimilarity(X: np.ndarray) -> np.float64:
-    ''' 
+    '''
     Computes the multilinear angular disimilarity.
     When given an m x 2 data matrix, it is equivalent
     to the angular distance.
@@ -427,13 +490,6 @@ def correlation_ratio(X: np.ndarray, y: np.ndarray) -> np.float64:
     References
     ----------
     .. [1] "Correlation Ratio", https://en.wikipedia.org/wiki/Correlation_ratio
-
-    Examples
-    --------
-    >>> import numpy as np
-    >>> data = np.arange(100).reshape(10,10)
-    >>> y = np.arange(10)
-    >>> correlation_ratio(data, y)
     '''
     raise NotImplementedError
     global_means = np.mean(X, axis=0)
@@ -541,7 +597,7 @@ def signum_correlation(X: np.ndarray) -> np.float64:
     This function estimates
 
     .. math::
-        R_c \\left[ X_1, \\cdots, X_n \\right] = \\frac{\\mathbb{E} \\left[ \\prod_{j=1}^{n} \\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right) \\right]}{\\prod_{j=1}^{n} \\sqrt[n]{\\mathbb{E}\\left[ |\\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right)|^n \\right]}}
+        R_{\\{sign}} \\left[ X_1, \\cdots, X_n \\right] = \\frac{\\mathbb{E} \\left[ \\prod_{j=1}^{n} \\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right) \\right]}{\\prod_{j=1}^{n} \\sqrt[n]{\\mathbb{E}\\left[ |\\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right)|^n \\right]}}
 
     Parameters
     ----------
@@ -697,7 +753,7 @@ def wang_zheng_correlation(X: np.ndarray) -> np.float64:
     --------
     >>> import numpy as np
     >>> data = np.arange(100).reshape(10,10)
-    >>> conaction.estimators.wang_zheng_correlation(data)
+    >>> wang_zheng_correlation(data)
     1.0
     '''
     result = X.T
